export const PORT = process.env.PORT || 5000

export const TEMPLATE_REPO = 'https://github.com/yhjor1212/web-instant-templates.git'

export const PACKAGE_JSON = {
  scripts: {
    lint: 'eslint src --fix',
    flow: 'flow',
    redirect: "echo '/*    /index.html   200' > public/_redirects",
    build: 'NODE_ENV=production webpack -p && npm run redirect',
    start: 'per-env',
    'start:development': 'webpack-dev-server',
    'start:production': 'webpack -p && pushstate-server',
  },
  license: 'UNLICENSED',
  browserslist: [
    '> 10%',
    'last 2 versions',
    'not IE < 11',
  ],
  eslintConfig: {
    extends: 'eslint-config-airbnb',
    parser: 'babel-eslint',
    env: {
      browser: true,
      node: true,
    },
    globals: {
      React: true,
      classnames: true,
    },
    plugins: [
      'compat',
      'flowtype',
    ],
    rules: {
      semi: 0,
      'react/prefer-stateless-function': 0,
      'compat/compat': 2,
    },
  },
  babel: {
    presets: [
      ['latest', { modules: false }],
      'stage-2',
      'react',
      'react-optimize',
      'flow',
    ],
  },
}

export const DEPENDENCIES = [
  {
    name: 'Web Production',
    dev: false,
    packages: [
      // React and Redux related
      'react',
      'react-dom',
      'react-router-dom',
      'react-router-redux@next',
      'react-helmet',
      'react-sizes',
      'redux',
      'react-redux',
      'redux-thunk',
      'redux-actions',
      'classnames',
      'prop-types',
      'history',

      // Babel and Presets
      'babel-core',
      'babel-preset-latest',
      'babel-preset-stage-2',
      'babel-preset-react',
      'babel-preset-react-optimize',
      'babel-preset-flow',

      // Bundle
      'webpack',
      'webpack-dev-server',
      'webpack-brevity',
      'per-env',
      'pushstate-server',
      'offline-plugin',
      'react-loadable',

      // UI Components
      'normalize.css',
      'semantic-ui-css',
      'semantic-ui-react',
      'glamorous',
      'glamor',
      'react-burger-menu',
      'redux-burger-menu',
      'redbox-react',
      'react-loading',

      // Others
      'axios',
    ],
  },
  {
    name: 'Dev only',
    dev: true,
    packages: [
      'eslint',
      'eslint-plugin-import',
      'eslint-config-airbnb',
      'eslint-plugin-react',
      'eslint-plugin-jsx-a11y',
      'eslint-plugin-flowtype',
      'eslint-plugin-compat',
      'babel-eslint',
      'flow-bin',
      'react-hot-loader@next',
    ],
  },
]
